/*https://fonts.google.com/*/
@import url('https://fonts.googleapis.com/css2?family=Nunito+Sans:ital,opsz,wght@0,6..12,200..1000;1,6..12,200..1000&display=swap');
@import url('https://fonts.googleapis.com/css2?family=Ubuntu+Mono:ital,wght@0,400;0,700;1,400;1,700&display=swap');

body {
    font-family: 'Nunito Sans', sans-serif;
    background-color: #F3F3F3;
    min-width: 800px;
    max-width: 1400px;
    margin: 0 auto;
}

h1 {
    text-align: center;
}

/* Additional styles to ensure content stays within bounds */
#sync-app {
    width: 100%;
}

.sync-logs{
    font-family:'Ubuntu Mono', monospace;
}